@@ -45,9 +45,17 @@
 static GSwitchItXkbConfig gswic;
 static gboolean initedOk;
 
+static PostActivationCallback paCallback = NULL;
+static void *paCallbackUserData = NULL;
+
 static const char DISABLE_XMM_WARNING_KEY[] =
     "/desktop/gnome/peripherals/keyboard/disable_xmm_and_xkb_warning";
 
+typedef enum {
+	RESPONSE_USE_X,
+	RESPONSE_USE_GNOME
+} SysConfigChangedMsgResponse;
+
 static void
 activation_error (void)
 {
@@ -100,7 +108,11 @@ apply_settings (void)
 		gswic.overrideSettings = FALSE;
 		GSwitchItXkbConfigSave (&gswic);
 	} else {
-		if (!GSwitchItXkbConfigActivate (&gswic)) {
+		if (GSwitchItXkbConfigActivate (&gswic)) {
+			if (paCallback != NULL) {
+				(*paCallback) (paCallbackUserData);
+			}
+		} else {
 			g_warning
 			    ("Could not activate the XKB configuration");
 			activation_error ();
@@ -110,6 +122,74 @@ apply_settings (void)
 	GSwitchItXkbConfigTerm (&gswic);
 }
 
+static void
+gnome_settings_keyboard_xkb_sysconfig_changed_response (GtkDialog * dialog,
+							SysConfigChangedMsgResponse
+							what2do,
+							GSwitchItXkbConfig
+							* pgswicNow)
+{
+	switch (what2do) {
+	case RESPONSE_USE_X:
+		GSwitchItXkbConfigSave (pgswicNow);
+		break;
+	case RESPONSE_USE_GNOME:
+		/* Do absolutely nothing - just keep things the way they are */
+		break;
+	}
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+	GSwitchItXkbConfigTerm (pgswicNow);
+	g_free (pgswicNow);
+}
+
+static void
+gnome_settings_keyboard_xkb_analyze_sysconfig (void)
+{
+	GConfClient *confClient;
+	GSwitchItXkbConfig gswicWas, *pgswicNow;
+	gboolean isConfigChanged;
+
+	if (!initedOk)
+		return;
+	pgswicNow = g_new (GSwitchItXkbConfig, 1);
+	confClient = gconf_client_get_default ();
+	GSwitchItXkbConfigInit (&gswicWas, confClient);
+	GSwitchItXkbConfigInit (pgswicNow, confClient);
+	g_object_unref (confClient);
+	GSwitchItXkbConfigLoadSysBackup (&gswicWas);
+	GSwitchItXkbConfigLoadInitial (pgswicNow);
+
+	isConfigChanged = g_slist_length (gswicWas.layouts) &&
+	    !GSwitchItXkbConfigEquals (pgswicNow, &gswicWas);
+	/* config was changed!!! */
+	if (isConfigChanged) {
+		GtkWidget *msg = gtk_message_dialog_new_with_markup (NULL,
+								     0,
+								     GTK_MESSAGE_INFO,
+								     GTK_BUTTONS_NONE,
+/* !! temporary one */
+								     _
+								     ("The X system keyboard settings differ from your current GNOME "
+								      "keyboard settings.  Which set would you like to use?"));
+		gtk_dialog_add_buttons (GTK_DIALOG (msg),
+					_("Use X settings"),
+					RESPONSE_USE_X,
+					_("Use GNOME settings"),
+					RESPONSE_USE_GNOME, NULL);
+		gtk_dialog_set_default_response (GTK_DIALOG (msg),
+						 RESPONSE_USE_GNOME);
+		g_signal_connect (msg, "response",
+				  G_CALLBACK
+				  (gnome_settings_keyboard_xkb_sysconfig_changed_response),
+				  pgswicNow);
+		gtk_widget_show (msg);
+	}
+	GSwitchItXkbConfigSaveSysBackup (pgswicNow);
+	if (!isConfigChanged) 
+		g_free (pgswicNow);
+	GSwitchItXkbConfigTerm (&gswicWas);
+}
+
 static void
 gnome_settings_keyboard_xkb_chk_lcl_xmm_response (GtkDialog * dlg,
 						  gint response)
@@ -150,7 +230,7 @@ gnome_settings_keyboard_xkb_chk_lcl_xmm (void)
 								_
 								("You have a keyboard remapping file (%s) in your home directory whose contents will now be ignored."
 								 " You can use the keyboard preferences to restore them."),
-								fname);
+				fname);
 			g_signal_connect (msg, "response",
 					  G_CALLBACK
 					  (gnome_settings_keyboard_xkb_chk_lcl_xmm_response),
@@ -161,12 +241,21 @@ gnome_settings_keyboard_xkb_chk_lcl_xmm (void)
 	g_dir_close (homeDir);
 }
 
+void
+gnome_settings_keyboard_xkb_set_post_activation_callback
+    (PostActivationCallback fun, void *userData)
+{
+	paCallback = fun;
+	paCallbackUserData = userData;
+}
+
 void
 gnome_settings_keyboard_xkb_init (GConfClient * client)
 {
 	if (!XklInit (GDK_DISPLAY ())) {
-		XklBackupNamesProp ();
 		initedOk = TRUE;
+		XklBackupNamesProp ();
+		gnome_settings_keyboard_xkb_analyze_sysconfig ();
 		gnome_settings_keyboard_xkb_chk_lcl_xmm ();
 		gnome_settings_daemon_register_callback
 		    ("/desktop/gnome/peripherals/keyboard/xkb",
